==> carbon-component-mapper-3.20.13.tgz: package/esm/wizard/wizard.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["stepsInfo", "jumpToStep"],
    _excluded2 = ["title"],
    _excluded3 = ["stepsInfo", "buttonLabels", "ButtonSetProps", "BackButtonProps", "NextButtonProps", "SubmitButtonProps", "ProgressIndicatorProps", "vertical", "WizardBodyProps", "conditionalSubmitFlag"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import WizardCommon from '@data-driven-forms/common/wizard/wizard';
import FormSpy from "@data-driven-forms/react-form-renderer/form-spy";
import WizardContext from "@data-driven-forms/react-form-renderer/wizard-context";
import { Button, Column, Grid, Row } from 'carbon-components-react';
import { ProgressStep, ProgressIndicator } from 'carbon-components-react/lib/components/ProgressIndicator/ProgressIndicator';
var useStyles = createUseStyles({
  horizontalNav: {
    marginBottom: 48
  },
  buttonSet: {
    marginTop: 48,
    flexFirection: 'row-reverse',
    display: 'flex'
  },
  body: {
    '&>:not(:last-child)': {
      marginBottom: 32
    }
  }
});

var WizardNav = function WizardNav(_ref) {
  var stepsInfo = _ref.stepsInfo,
      jumpToStep = _ref.jumpToStep,
      props = _objectWithoutProperties(_ref, _excluded);

  var _useStyles = useStyles(),
      horizontalNav = _useStyles.horizontalNav;

  return /*#__PURE__*/React.createElement(ProgressIndicator, _extends({
    onChange: function onChange(index) {
      return props.currentIndex > index ? jumpToStep(index, true) : undefined;
    }
  }, props, {
    className: clsx(horizontalNav, props.className)
  }), stepsInfo.map(function (_ref2, index) {
    var title = _ref2.title,
        step = _objectWithoutProperties(_ref2, _excluded2);

    return /*#__PURE__*/React.createElement(ProgressStep, _extends({
      key: index,
      label: title,
      disabled: index > props.currentIndex
    }, step));
  }));
};

WizardNav.propTypes = {
  stepsInfo: PropTypes.arrayOf(PropTypes.shape({
    title: PropTypes.node
  })),
  currentIndex: PropTypes.number,
  jumpToStep: PropTypes.func,
  className: PropTypes.string
};
var defaultLabels = {
  submit: 'Submit',
  back: 'Back',
  next: 'Next'
};

var Layout = function Layout(_ref3) {
  var nav = _ref3.nav,
      fields = _ref3.fields,
      WizardBodyProps = _ref3.WizardBodyProps;

  var _useStyles2 = useStyles(),
      body = _useStyles2.body;

  return /*#__PURE__*/React.createElement(React.Fragment, null, nav, /*#__PURE__*/React.createElement("div", _extends({}, WizardBodyProps, {
    className: clsx(body, WizardBodyProps === null || WizardBodyProps === void 0 ? void 0 : WizardBodyProps.className)
  }), fields));
};

Layout.propTypes = {
  nav: PropTypes.node,
  fields: PropTypes.node,
  WizardBodyProps: PropTypes.object
};

var VerticalLayout = function VerticalLayout(_ref4) {
  var nav = _ref4.nav,
      fields = _ref4.fields,
      WizardBodyProps = _ref4.WizardBodyProps;

  var _useStyles3 = useStyles(),
      body = _useStyles3.body;

  return /*#__PURE__*/React.createElement(Grid, {
    narrow: true
  }, /*#__PURE__*/React.createElement(Row, null, /*#__PURE__*/React.createElement(Column, {
    sm: 1,
    md: 2,
    lg: 3
  }, nav), /*#__PURE__*/React.createElement(Column, _extends({}, WizardBodyProps, {
    className: clsx(body, WizardBodyProps === null || WizardBodyProps === void 0 ? void 0 : WizardBodyProps.className)
  }), fields)));
};

VerticalLayout.propTypes = {
  nav: PropTypes.node,
  fields: PropTypes.node,
  WizardBodyProps: PropTypes.object
};

var WizardInternal = function WizardInternal(_ref5) {
  var stepsInfo = _ref5.stepsInfo,
      buttonLabels = _ref5.buttonLabels,
      ButtonSetProps = _ref5.ButtonSetProps,
      BackButtonProps = _ref5.BackButtonProps,
      NextButtonProps = _ref5.NextButtonProps,
      SubmitButtonProps = _ref5.SubmitButtonProps,
      ProgressIndicatorProps = _ref5.ProgressIndicatorProps,
      vertical = _ref5.vertical,
      WizardBodyProps = _ref5.WizardBodyProps,
      conditionalSubmitFlag = _ref5.conditionalSubmitFlag,
      props = _objectWithoutProperties(_ref5, _excluded3);

  var _useContext = useContext(WizardContext),
      formOptions = _useContext.formOptions,
      currentStep = _useContext.currentStep,
      handlePrev = _useContext.handlePrev,
      onKeyDown = _useContext.onKeyDown,
      handleNext = _useContext.handleNext,
      activeStepIndex = _useContext.activeStepIndex,
      selectNext = _useContext.selectNext,
      jumpToStep = _useContext.jumpToStep;

  var _useStyles4 = useStyles(),
      buttonSet = _useStyles4.buttonSet;

  var finalButtoLabels = _objectSpread(_objectSpread({}, defaultLabels), buttonLabels);

  var nav = stepsInfo && /*#__PURE__*/React.createElement(WizardNav, _extends({
    vertical: vertical,
    stepsInfo: stepsInfo,
    currentIndex: activeStepIndex,
    jumpToStep: jumpToStep
  }, ProgressIndicatorProps));
  var fields = currentStep.fields.map(function (item) {
    return formOptions.renderForm([item], formOptions);
  });
  var WizardLayout = vertical && nav ? VerticalLayout : Layout;
  return /*#__PURE__*/React.createElement("div", _extends({
    onKeyDown: onKeyDown
  }, props), /*#__PURE__*/React.createElement(WizardLayout, {
    nav: nav ? nav : null,
    fields: fields,
    WizardBodyProps: WizardBodyProps
  }), /*#__PURE__*/React.createElement(FormSpy, null, function (_ref6) {
    var invalid = _ref6.invalid,
        validating = _ref6.validating,
        submitting = _ref6.submitting;
    var nextResult = currentStep.nextStep ? selectNext(currentStep.nextStep, formOptions.getState) : currentStep.nextStep;
    var progressNext = nextResult !== conditionalSubmitFlag && currentStep.nextStep;
    return /*#__PURE__*/React.createElement("div", _extends({}, ButtonSetProps, {
      className: clsx(buttonSet, ButtonSetProps.className)
    }), progressNext ? /*#__PURE__*/React.createElement(Button, _extends({
      onClick: function onClick() {
        return handleNext(nextResult);
      },
      disabled: !formOptions.valid || invalid || validating || submitting
    }, NextButtonProps), finalButtoLabels.next) : /*#__PURE__*/React.createElement(Button, _extends({
      onClick: function onClick() {
        return formOptions.handleSubmit();
      },
      disabled: !formOptions.valid || invalid || validating || submitting
    }, SubmitButtonProps), finalButtoLabels.submit), /*#__PURE__*/React.createElement(Button, _extends({
      kind: "secondary",
      onClick: handlePrev,
      disabled: activeStepIndex === 0
    }, BackButtonProps), finalButtoLabels.back));
  }));
};

WizardInternal.propTypes = {
  stepsInfo: PropTypes.arrayOf(PropTypes.shape({
    title: PropTypes.node
  })),
  buttonLabels: PropTypes.shape({
    submit: PropTypes.node,
    back: PropTypes.node,
    next: PropTypes.node
  }),
  BackButtonProps: PropTypes.object,
  NextButtonProps: PropTypes.object,
  SubmitButtonProps: PropTypes.object,
  ButtonSetProps: PropTypes.object,
  ProgressIndicatorProps: PropTypes.object,
  vertical: PropTypes.bool,
  WizardBodyProps: PropTypes.object,
  conditionalSubmitFlag: PropTypes.string.isRequired
};
WizardInternal.defaultProps = {
  BackButtonProps: {},
  NextButtonProps: {},
  SubmitButtonProps: {},
  ButtonSetProps: {},
  ProgressIndicatorProps: {},
  WizardBodyProps: {}
};

var Wizard = function Wizard(props) {
  return /*#__PURE__*/React.createElement(WizardCommon, _extends({
    Wizard: WizardInternal
  }, props));
};

export default Wizard;

==> carbon-component-mapper-3.23.3.tgz: package/esm/wizard/wizard.js <==
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
var _excluded = ["stepsInfo", "jumpToStep"],
    _excluded2 = ["title"],
    _excluded3 = ["stepsInfo", "buttonLabels", "ButtonSetProps", "BackButtonProps", "NextButtonProps", "SubmitButtonProps", "ProgressIndicatorProps", "vertical", "WizardBodyProps", "conditionalSubmitFlag"];

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

import React, { useContext } from 'react';
import PropTypes from 'prop-types';
import clsx from 'clsx';
import { createUseStyles } from "react-jss/dist/react-jss.esm.js";
import WizardCommon from '@data-driven-forms/common/wizard/wizard';
import FormSpy from "@data-driven-forms/react-form-renderer/form-spy";
import WizardContext from "@data-driven-forms/react-form-renderer/wizard-context";
import { Button, Column, Grid, Row } from 'carbon-components-react';
import { ProgressStep, ProgressIndicator } from 'carbon-components-react/lib/components/ProgressIndicator/ProgressIndicator';
var useStyles = createUseStyles({
  horizontalNav: {
    marginBottom: 48
  },
  buttonSet: {
    marginTop: 48,
    flexFirection: 'row-reverse',
    display: 'flex'
  },
  body: {
    '&>:not(:last-child)': {
      marginBottom: 32
    }
  }
});

var WizardNav = function WizardNav(_ref) {
  var stepsInfo = _ref.stepsInfo,
      jumpToStep = _ref.jumpToStep,
      props = _objectWithoutProperties(_ref, _excluded);

  var _useStyles = useStyles(),
      horizontalNav = _useStyles.horizontalNav;

  return /*#__PURE__*/React.createElement(ProgressIndicator, _extends({
    onChange: function onChange(index) {
      return props.currentIndex > index ? jumpToStep(index, true) : undefined;
    }
  }, props, {
    className: clsx(horizontalNav, props.className)
  }), stepsInfo.map(function (_ref2, index) {
    var title = _ref2.title,
        step = _objectWithoutProperties(_ref2, _excluded2);

    return /*#__PURE__*/React.createElement(ProgressStep, _extends({
      key: index,
      label: title,
      disabled: index > props.currentIndex
    }, step));
  }));
};

WizardNav.propTypes = {
  stepsInfo: PropTypes.arrayOf(PropTypes.shape({
    title: PropTypes.node
  })),
  currentIndex: PropTypes.number,
  jumpToStep: PropTypes.func,
  className: PropTypes.string
};
var defaultLabels = {
  submit: 'Submit',
  back: 'Back',
  next: 'Next'
};

var Layout = function Layout(_ref3) {
  var nav = _ref3.nav,
      fields = _ref3.fields,
      WizardBodyProps = _ref3.WizardBodyProps;

  var _useStyles2 = useStyles(),
      body = _useStyles2.body;

  return /*#__PURE__*/React.createElement(React.Fragment, null, nav, /*#__PURE__*/React.createElement("div", _extends({}, WizardBodyProps, {
    className: clsx(body, WizardBodyProps === null || WizardBodyProps === void 0 ? void 0 : WizardBodyProps.className)
  }), fields));
};

Layout.propTypes = {
  nav: PropTypes.node,
  fields: PropTypes.node,
  WizardBodyProps: PropTypes.object
};

var VerticalLayout = function VerticalLayout(_ref4) {
  var nav = _ref4.nav,
      fields = _ref4.fields,
      WizardBodyProps = _ref4.WizardBodyProps;

  var _useStyles3 = useStyles(),
      body = _useStyles3.body;

  return /*#__PURE__*/React.createElement(Grid, {
    narrow: true
  }, /*#__PURE__*/React.createElement(Row, null, /*#__PURE__*/React.createElement(Column, {
    sm: 1,
    md: 2,
    lg: 3
  }, nav), /*#__PURE__*/React.createElement(Column, _extends({}, WizardBodyProps, {
    className: clsx(body, WizardBodyProps === null || WizardBodyProps === void 0 ? void 0 : WizardBodyProps.className)
  }), fields)));
};

VerticalLayout.propTypes = {
  nav: PropTypes.node,
  fields: PropTypes.node,
  WizardBodyProps: PropTypes.object
};

var WizardInternal = function WizardInternal(_ref5) {
  var stepsInfo = _ref5.stepsInfo,
      buttonLabels = _ref5.buttonLabels,
      _ref5$ButtonSetProps = _ref5.ButtonSetProps,
      ButtonSetProps = _ref5$ButtonSetProps === void 0 ? {} : _ref5$ButtonSetProps,
      _ref5$BackButtonProps = _ref5.BackButtonProps,
      BackButtonProps = _ref5$BackButtonProps === void 0 ? {} : _ref5$BackButtonProps,
      _ref5$NextButtonProps = _ref5.NextButtonProps,
      NextButtonProps = _ref5$NextButtonProps === void 0 ? {} : _ref5$NextButtonProps,
      _ref5$SubmitButtonPro = _ref5.SubmitButtonProps,
      SubmitButtonProps = _ref5$SubmitButtonPro === void 0 ? {} : _ref5$SubmitButtonPro,
      _ref5$ProgressIndicat = _ref5.ProgressIndicatorProps,
      ProgressIndicatorProps = _ref5$ProgressIndicat === void 0 ? {} : _ref5$ProgressIndicat,
      vertical = _ref5.vertical,
      _ref5$WizardBodyProps = _ref5.WizardBodyProps,
      WizardBodyProps = _ref5$WizardBodyProps === void 0 ? {} : _ref5$WizardBodyProps,
      conditionalSubmitFlag = _ref5.conditionalSubmitFlag,
      props = _objectWithoutProperties(_ref5, _excluded3);

  var _useContext = useContext(WizardContext),
      formOptions = _useContext.formOptions,
      currentStep = _useContext.currentStep,
      handlePrev = _useContext.handlePrev,
      onKeyDown = _useContext.onKeyDown,
      handleNext = _useContext.handleNext,
      activeStepIndex = _useContext.activeStepIndex,
      selectNext = _useContext.selectNext,
      jumpToStep = _useContext.jumpToStep;

  var _useStyles4 = useStyles(),
      buttonSet = _useStyles4.buttonSet;

  var finalButtoLabels = _objectSpread(_objectSpread({}, defaultLabels), buttonLabels);

  var nav = stepsInfo && /*#__PURE__*/React.createElement(WizardNav, _extends({
    vertical: vertical,
    stepsInfo: stepsInfo,
    currentIndex: activeStepIndex,
    jumpToStep: jumpToStep
  }, ProgressIndicatorProps));
  var fields = currentStep.fields.map(function (item) {
    return formOptions.renderForm([item], formOptions);
  });
  var WizardLayout = vertical && nav ? VerticalLayout : Layout;
  return /*#__PURE__*/React.createElement("div", _extends({
    onKeyDown: onKeyDown
  }, props), /*#__PURE__*/React.createElement(WizardLayout, {
    nav: nav ? nav : null,
    fields: fields,
    WizardBodyProps: WizardBodyProps
  }), /*#__PURE__*/React.createElement(FormSpy, null, function (_ref6) {
    var invalid = _ref6.invalid,
        validating = _ref6.validating,
        submitting = _ref6.submitting;
    var nextResult = currentStep.nextStep ? selectNext(currentStep.nextStep, formOptions.getState) : currentStep.nextStep;
    var progressNext = nextResult !== conditionalSubmitFlag && currentStep.nextStep;
    return /*#__PURE__*/React.createElement("div", _extends({}, ButtonSetProps, {
      className: clsx(buttonSet, ButtonSetProps.className)
    }), progressNext ? /*#__PURE__*/React.createElement(Button, _extends({
      onClick: function onClick() {
        return handleNext(nextResult);
      },
      disabled: !formOptions.valid || invalid || validating || submitting
    }, NextButtonProps), finalButtoLabels.next) : /*#__PURE__*/React.createElement(Button, _extends({
      onClick: function onClick() {
        return formOptions.handleSubmit();
      },
      disabled: !formOptions.valid || invalid || validating || submitting
    }, SubmitButtonProps), finalButtoLabels.submit), /*#__PURE__*/React.createElement(Button, _extends({
      kind: "secondary",
      onClick: handlePrev,
      disabled: activeStepIndex === 0
    }, BackButtonProps), finalButtoLabels.back));
  }));
};

WizardInternal.propTypes = {
  stepsInfo: PropTypes.arrayOf(PropTypes.shape({
    title: PropTypes.node
  })),
  buttonLabels: PropTypes.shape({
    submit: PropTypes.node,
    back: PropTypes.node,
    next: PropTypes.node
  }),
  BackButtonProps: PropTypes.object,
  NextButtonProps: PropTypes.object,
  SubmitButtonProps: PropTypes.object,
  ButtonSetProps: PropTypes.object,
  ProgressIndicatorProps: PropTypes.object,
  vertical: PropTypes.bool,
  WizardBodyProps: PropTypes.object,
  conditionalSubmitFlag: PropTypes.string.isRequired
};

var Wizard = function Wizard(props) {
  return /*#__PURE__*/React.createElement(WizardCommon, _extends({
    Wizard: WizardInternal
  }, props));
};

export default Wizard;
